@@ -101,11 +101,15 @@ class ZephyrSession:
             params.update(parse_qs(params_str))
         return
 
-    def post_file(self, endpoint: str, file_path: str, **kwargs):
+    def post_file(self, endpoint: str, file_path: str, to_files=None, **kwargs):
         """
         Post wrapper to send a file. Handles single file opening,
         sending its content and closing
         """
         with open(file_path, "rb") as file:
             files = {"file": file}
+
+            if to_files:
+                files.update(to_files)
+
             return self._request("post", endpoint, files=files, **kwargs)
